@@ -30,8 +30,9 @@ class Repository:
         def auto_detach(session):
             Session.detach(session)
 
-        event.listen(Session, 'init', auto_add)
+        # event.listen(Session, 'init', auto_add)
         event.listen(Session, 'after_commit', auto_detach)
+        event.listen(Session, 'append', auto_add)
   
     def save(self, entity: any) -> None:
         '''
