@@ -1,6 +1,8 @@
 from scrapeanything.scraper.scraper import Scraper
 
-from selenium import webdriver
+import undetected_chromedriver.v2 as webdriver
+
+# from selenium import webdriver
 from selenium.webdriver.common.keys import Keys
 from selenium import webdriver
 from selenium.webdriver.support.wait import WebDriverWait
@@ -22,7 +24,16 @@ class Selenium(Scraper):
 
     def __init__(self, headless: bool=True, window: dict={}):
         options = webdriver.ChromeOptions()
-        
+
+        #region undetected_chromedriver
+        # setting profile
+        options.user_data_dir = "c:\\temp\\profile"
+        # another way to set profile is the below (which takes precedence if both variants are used
+        options.add_argument('--user-data-dir=c:\\temp\\profile2')
+        # just some options passing in to skip annoying popups
+        options.add_argument('--no-first-run --no-service-autorun --password-store=basic')
+        #endregion undetected_chromedriver
+
         options.add_argument('--no-sandbox')
         options.add_argument('--log-level=3')
         options.add_argument('disable-infobars')
